#ifndef CONFIG_H
#define CONFIG_H

#define HAVE_SYSCONF_PROTO 1
#define HAVE_GETRUSAGE_PROTO 1
/* #undef HAVE_NAUTY */
/* #undef HAVE_NTL */
#define HAVE_BLISS 1
/* #undef HAVE_EIGEN */

#define HAVE_UINT 1
#define HAVE_ULONG 1
#define HAVE_SYS_TYPES_H 1
#define HAVE_STDINT_H 1
#define HAVE_STDDEF_H 1

#define SYMPOL_VERSION "0.1.9"

#endif //CONFIG_H
